@@ -7,13 +7,16 @@ class Viper:
         self.name = name
         self.tests = []
         self.passed = 0
-        print("This is Viper, a modern testing framework, created by Aarush Gupta (https://aarushgupta.tk)")
 
     def clean(self):
         for test in self.tests:
             if type(test["desiredOutput"]) == list:
                 test["array"] = True
     
+    def importFromFile(self, data):
+        for test in data:
+            self.test(test["name"], test["functionOutput"], test["desiredOutput"])
+    
     def test(self, name, function, output):
         """
         Create a test\n
@@ -30,6 +33,7 @@ class Viper:
 
     def evaluate(self):
         """ Evaluate all the tests """
+        print("This is Viper, a modern testing framework, created by Aarush Gupta (https://aarushgupta.tk)")
         print(f"Running tests for \"{self.name}\"")
         start = time.perf_counter()
         for test in self.tests:
